@@ -164,6 +164,13 @@ def setup_parser() -> argparse.ArgumentParser:
         action="store_true",
         help="adds TPC column to output using information from AP beacon 802.11h",
     )
+    parser.add_argument(
+        "--mfp",
+        "--pmf",
+        dest="pmf",
+        action="store_true",
+        help="adds Protected Management Frame column to output using information from AP beacon RSNE",
+    )
     parser.add_argument(
         "--interval",
         dest="interval",
